v1alpha1

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 20, 2026 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package v1alpha1 contains API Schema definitions for the privateca-issuer v1alpha1 API group +kubebuilder:object:generate=true +groupName=privateca-issuer.ncloud.com

Index

Constants

This section is empty.

Variables

var (
	// GroupVersion is group version used to register these objects
	GroupVersion = schema.GroupVersion{Group: "privateca-issuer.ncloud.com", Version: "v1alpha1"}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type ConditionStatus

type ConditionStatus string

ConditionStatus represents a condition's status. +kubebuilder:validation:Enum=True;False;Unknown

const (
	ConditionTrue    ConditionStatus = "True"
	ConditionFalse   ConditionStatus = "False"
	ConditionUnknown ConditionStatus = "Unknown"
)

type NcloudCredentialsRef added in v0.2.0

type NcloudCredentialsRef struct {
	// Name of the Secret. Required when CredentialsRef is set.
	// +optional
	Name string `json:"name,omitempty"`

	// Namespace of the Secret. Required for ClusterIssuer; ignored for namespaced Issuer.
	// +optional
	Namespace string `json:"namespace,omitempty"`

	// AccessKeyField is the Secret data key holding the NCloud access key.
	// +kubebuilder:default=NCLOUD_ACCESS_KEY
	AccessKeyField string `json:"accessKeyField,omitempty"`

	// SecretKeyField is the Secret data key holding the NCloud secret key.
	// +kubebuilder:default=NCLOUD_SECRET_KEY
	SecretKeyField string `json:"secretKeyField,omitempty"`
}

NcloudCredentialsRef points to the Secret that stores the NCloud API access and secret keys.

func (*NcloudCredentialsRef) DeepCopy added in v0.2.0

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NcloudCredentialsRef.

func (*NcloudCredentialsRef) DeepCopyInto added in v0.2.0

func (in *NcloudCredentialsRef) DeepCopyInto(out *NcloudCredentialsRef)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type NcloudPCAClusterIssuer

type NcloudPCAClusterIssuer struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   NcloudPCAIssuerSpec   `json:"spec,omitempty"`
	Status NcloudPCAIssuerStatus `json:"status,omitempty"`
}

NcloudPCAClusterIssuer is the Schema for the ncloudpcaclusterissuers API

func (*NcloudPCAClusterIssuer) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NcloudPCAClusterIssuer.

func (*NcloudPCAClusterIssuer) DeepCopyInto

func (in *NcloudPCAClusterIssuer) DeepCopyInto(out *NcloudPCAClusterIssuer)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*NcloudPCAClusterIssuer) DeepCopyObject

func (in *NcloudPCAClusterIssuer) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type NcloudPCAClusterIssuerList

type NcloudPCAClusterIssuerList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []NcloudPCAClusterIssuer `json:"items"`
}

NcloudPCAClusterIssuerList contains a list of NcloudPCAClusterIssuer

func (*NcloudPCAClusterIssuerList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NcloudPCAClusterIssuerList.

func (*NcloudPCAClusterIssuerList) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*NcloudPCAClusterIssuerList) DeepCopyObject

func (in *NcloudPCAClusterIssuerList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type NcloudPCAIssuer

type NcloudPCAIssuer struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   NcloudPCAIssuerSpec   `json:"spec,omitempty"`
	Status NcloudPCAIssuerStatus `json:"status,omitempty"`
}

NcloudPCAIssuer is the Schema for the ncloudpcaissuers API

func (*NcloudPCAIssuer) DeepCopy

func (in *NcloudPCAIssuer) DeepCopy() *NcloudPCAIssuer

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NcloudPCAIssuer.

func (*NcloudPCAIssuer) DeepCopyInto

func (in *NcloudPCAIssuer) DeepCopyInto(out *NcloudPCAIssuer)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*NcloudPCAIssuer) DeepCopyObject

func (in *NcloudPCAIssuer) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type NcloudPCAIssuerCondition

type NcloudPCAIssuerCondition struct {
	// Type of the condition, currently ('Ready').
	Type NcloudPCAIssuerConditionType `json:"type"`

	// Status of the condition, one of ('True', 'False', 'Unknown').
	Status ConditionStatus `json:"status"`

	// LastTransitionTime is the timestamp corresponding to the last status
	// change of this condition.
	// +optional
	LastTransitionTime *metav1.Time `json:"lastTransitionTime,omitempty"`

	// Reason is a brief machine readable explanation for the condition's last
	// transition.
	// +optional
	Reason string `json:"reason,omitempty"`

	// Message is a human readable description of the details of the last
	// transition, complementing reason.
	// +optional
	Message string `json:"message,omitempty"`
}

NcloudPCAIssuerCondition contains condition information for a PCA Issuer.

func (*NcloudPCAIssuerCondition) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NcloudPCAIssuerCondition.

func (*NcloudPCAIssuerCondition) DeepCopyInto

func (in *NcloudPCAIssuerCondition) DeepCopyInto(out *NcloudPCAIssuerCondition)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type NcloudPCAIssuerConditionType

type NcloudPCAIssuerConditionType string

NcloudPCAIssuerConditionType represents an Issuer condition value.

const (
	// IssuerConditionReady represents the fact that a given Issuer condition
	// is in ready state and able to issue certificates.
	// If the `status` of this condition is `False`, CertificateRequest controllers
	// should prevent attempts to sign certificates.
	IssuerConditionReady NcloudPCAIssuerConditionType = "Ready"
)

type NcloudPCAIssuerList

type NcloudPCAIssuerList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []NcloudPCAIssuer `json:"items"`
}

NcloudPCAIssuerList contains a list of NcloudPCAIssuer

func (*NcloudPCAIssuerList) DeepCopy

func (in *NcloudPCAIssuerList) DeepCopy() *NcloudPCAIssuerList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NcloudPCAIssuerList.

func (*NcloudPCAIssuerList) DeepCopyInto

func (in *NcloudPCAIssuerList) DeepCopyInto(out *NcloudPCAIssuerList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*NcloudPCAIssuerList) DeepCopyObject

func (in *NcloudPCAIssuerList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type NcloudPCAIssuerSpec

type NcloudPCAIssuerSpec struct {
	// CaTag is the Private CA tag ID shown on the NCloud console.
	// +kubebuilder:validation:Required
	// +kubebuilder:validation:MinLength=1
	CaTag string `json:"caTag"`

	// Region selects the NCloud realm. Determines the API gateway URL.
	// +kubebuilder:validation:Enum=public;gov;fin
	// +kubebuilder:default=public
	Region string `json:"region,omitempty"`

	// APIGatewayURL overrides the region-derived API gateway URL.
	// Advanced use only (e.g. private gateway, testing). Leave empty to use Region.
	// +optional
	APIGatewayURL string `json:"apiGatewayUrl,omitempty"`

	// CredentialsRef references the Secret containing NCloud API credentials.
	// Omit to authenticate using the NKS node's ServerRole (IAM role) — see
	// https://guide.ncloud-docs.com/docs/kubernetes-node-iam-role.
	// +optional
	CredentialsRef NcloudCredentialsRef `json:"credentialsRef,omitempty"`
}

NcloudPCAIssuerSpec defines the desired state of a Ncloud Private CA Issuer.

func (*NcloudPCAIssuerSpec) DeepCopy

func (in *NcloudPCAIssuerSpec) DeepCopy() *NcloudPCAIssuerSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NcloudPCAIssuerSpec.

func (*NcloudPCAIssuerSpec) DeepCopyInto

func (in *NcloudPCAIssuerSpec) DeepCopyInto(out *NcloudPCAIssuerSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type NcloudPCAIssuerStatus

type NcloudPCAIssuerStatus struct {
	Conditions []NcloudPCAIssuerCondition `json:"conditions,omitempty"`
}

NcloudPCAIssuerStatus defines the observed state of NcloudPCAIssuer.

func (*NcloudPCAIssuerStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NcloudPCAIssuerStatus.

func (*NcloudPCAIssuerStatus) DeepCopyInto

func (in *NcloudPCAIssuerStatus) DeepCopyInto(out *NcloudPCAIssuerStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to