Documentation
¶
Index ¶
- func CacheExpires(r *http.Response) time.Time
- func NewConfiguration(apiKeys ...*ncloud.APIKey) *ncloud.Configuration
- type APIClient
- type APIResponse
- type ActivateSubCa
- type ActivateSubCaResponse
- type AddCaUser
- type BaseResponse
- type CaCertInfo
- type CaInfo
- type CaInfoUrlInfo
- type CreateCa
- type CreateCaResponse
- type CreateCaResponseData
- type CreateEndCert
- type GetCaInfoResponse
- type GetChainResponse
- type GetCrlResponse
- type GetEndCertInfoResponse
- type GetEndCertInfoResponseData
- type IssueEndCertResponse
- type IssueEndCertResponseData
- type ListCaResponse
- type ListCaResponseData
- type ListCaUsersResponse
- type ListCaUsersResponseData
- type ListIssuedEndCertsResponse
- type ListIssuedEndCertsResponseData
- type ModifyOcspUrl
- type ResponseCode
- type SignCsr
- type SignCsrResponse
- type SignCsrResponseData
- type UpdateCa
- type UpdateCaResponse
- type UpdateCrlConfig
- type V1ApiService
- func (a *V1ApiService) CaCaTagActivatePost(ctx context.Context, activateSubCa *ActivateSubCa, caTag *string) (*ActivateSubCaResponse, error)
- func (a *V1ApiService) CaCaTagCertGet(ctx context.Context, caTag *string, localVarOptionals map[string]interface{}) (*ListIssuedEndCertsResponse, error)
- func (a *V1ApiService) CaCaTagCertPost(ctx context.Context, createEndCert *CreateEndCert, caTag *string) (*IssueEndCertResponse, error)
- func (a *V1ApiService) CaCaTagCertSerialNoGet(ctx context.Context, caTag *string, serialNo *string) (*GetEndCertInfoResponse, error)
- func (a *V1ApiService) CaCaTagCertSerialNoRevokePost(ctx context.Context, caTag *string, serialNo *string) (*BaseResponse, error)
- func (a *V1ApiService) CaCaTagCertSignPost(ctx context.Context, signCsr *SignCsr, caTag *string, ...) (*SignCsrResponse, error)
- func (a *V1ApiService) CaCaTagChainGet(ctx context.Context, caTag *string) (*GetChainResponse, error)
- func (a *V1ApiService) CaCaTagCrlConfigGet(ctx context.Context, caTag *string) error
- func (a *V1ApiService) CaCaTagCrlConfigPut(ctx context.Context, updateCrlConfig *UpdateCrlConfig, caTag *string) error
- func (a *V1ApiService) CaCaTagCrlGet(ctx context.Context, caTag *string) (*GetCrlResponse, error)
- func (a *V1ApiService) CaCaTagDelete(ctx context.Context, caTag *string) (*BaseResponse, error)
- func (a *V1ApiService) CaCaTagGet(ctx context.Context, caTag *string) (*GetCaInfoResponse, error)
- func (a *V1ApiService) CaCaTagPut(ctx context.Context, updateCa *UpdateCa, caTag *string) (*UpdateCaResponse, error)
- func (a *V1ApiService) CaCaTagSubCsrGet(ctx context.Context, caTag *string) error
- func (a *V1ApiService) CaCaTagSubSignPost(ctx context.Context, signCsr *SignCsr, caTag *string) error
- func (a *V1ApiService) CaCaTagTrimPost(ctx context.Context, caTag *string) error
- func (a *V1ApiService) CaCaTagUrlsDelete(ctx context.Context, caTag *string) error
- func (a *V1ApiService) CaCaTagUrlsPut(ctx context.Context, modifyOcspUrl *ModifyOcspUrl, caTag *string) error
- func (a *V1ApiService) CaCaTagUsersGet(ctx context.Context, caTag *string) (*ListCaUsersResponse, error)
- func (a *V1ApiService) CaCaTagUsersIdNoDelete(ctx context.Context, caTag *string, idNo *string) (*BaseResponse, error)
- func (a *V1ApiService) CaCaTagUsersPost(ctx context.Context, addCaUser *AddCaUser, caTag *string) (*BaseResponse, error)
- func (a *V1ApiService) CaGet(ctx context.Context, localVarOptionals map[string]interface{}) (*ListCaResponse, error)
- func (a *V1ApiService) CaPost(ctx context.Context, createCa *CreateCa, caType *string, ...) (*CreateCaResponse, error)
- type X509CaParameters
- type X509EndCertParameters
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CacheExpires ¶
CacheExpires helper function to determine remaining time before repeating a request.
func NewConfiguration ¶
func NewConfiguration(apiKeys ...*ncloud.APIKey) *ncloud.Configuration
Types ¶
type APIClient ¶
type APIClient struct {
// API Services
V1Api *V1ApiService
// contains filtered or unexported fields
}
APIClient manages communication with the api API v2022-05-11T10:25:28Z In most cases there should be only one, shared, APIClient.
func NewAPIClient ¶
func NewAPIClient(cfg *ncloud.Configuration) *APIClient
NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.
func (*APIClient) ChangeBasePath ¶
Change base path to allow switching to mocks
type APIResponse ¶
type APIResponse struct {
*http.Response `json:"-"`
Message string `json:"message,omitempty"`
// Operation is the name of the swagger operation.
Operation string `json:"operation,omitempty"`
// RequestURL is the request URL. This value is always available, even if the
// embedded *http.Response is nil.
RequestURL string `json:"url,omitempty"`
// Method is the HTTP method used for the request. This value is always
// available, even if the embedded *http.Response is nil.
Method string `json:"method,omitempty"`
// Payload holds the contents of the response body (which may be nil or empty).
// This is provided here as the raw response.Body() reader will have already
// been drained.
Payload []byte `json:"-"`
}
func NewAPIResponse ¶
func NewAPIResponse(r *http.Response) *APIResponse
func NewAPIResponseWithError ¶
func NewAPIResponseWithError(errorMessage string) *APIResponse
type ActivateSubCa ¶
type ActivateSubCaResponse ¶
type ActivateSubCaResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *CreateCaResponseData `json:"data,omitempty"`
}
type BaseResponse ¶
type BaseResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *interface{} `json:"data,omitempty"`
}
type CaCertInfo ¶
type CaCertInfo struct {
// Ca Cert Id
CaCertId *float32 `json:"caCertId,omitempty"`
// 인증서 이름
CommonName *string `json:"commonName,omitempty"`
// 인증서 발행자 이름
IssuerName *string `json:"issuerName,omitempty"`
// 인증서 유효 기간
NotBeforeDate *float32 `json:"notBeforeDate,omitempty"`
// 인증서 만료 기간
NotAfterDate *float32 `json:"notAfterDate,omitempty"`
// 공개키 알고리즘
PublicKeyAlgorithm *string `json:"publicKeyAlgorithm,omitempty"`
// 서명 알고리즘
SignatureAlgorithm *string `json:"signatureAlgorithm,omitempty"`
// 시리얼 번호
SerialNo *string `json:"serialNo,omitempty"`
// 국가
Country *string `json:"country,omitempty"`
// 구/동
StateProvince *string `json:"stateProvince,omitempty"`
// 도시
Locality *string `json:"locality,omitempty"`
// 회사
Organization *string `json:"organization,omitempty"`
// 조직
OrganizationUnit *string `json:"organizationUnit,omitempty"`
// Pem 형식 인증서
CertPem *string `json:"certPem,omitempty"`
// Pem 형식 인증서 체인
ChainPem *string `json:"chainPem,omitempty"`
}
type CaInfo ¶
type CaInfo struct {
// Ca Id
CaId *int32 `json:"caId,omitempty"`
// 별칭
Alias *string `json:"alias,omitempty"`
// Ca tag
CaTag *string `json:"caTag,omitempty"`
// CA 상태 변경
Status *string `json:"status,omitempty"`
// 상태 변경 일시
StatusUpdateDate *float32 `json:"statusUpdateDate,omitempty"`
// 등록 일시
RgstDate *float32 `json:"rgstDate,omitempty"`
// Ca 타입
CaType *string `json:"caType,omitempty"`
// 메모
Memo *string `json:"memo,omitempty"`
// 인증서 서명 개수
SigningCount *float32 `json:"signingCount,omitempty"`
UrlInfo *CaInfoUrlInfo `json:"urlInfo,omitempty"`
}
type CaInfoUrlInfo ¶
type CaInfoUrlInfo struct {
// Ca 배포 Url
Ca *[]string `json:"ca,omitempty"`
// Crl 배포 Url
Crl *[]string `json:"crl,omitempty"`
// Ocsp 질의 Url
Ocsp *[]string `json:"ocsp,omitempty"`
}
배포 Urls
type CreateCa ¶
type CreateCa struct {
// 별칭
Alias *string `json:"alias"`
// 메모
Memo *string `json:"memo,omitempty"`
// 키 타입
KeyType *string `json:"keyType"`
// 일 단위 인증서 유효 기간. (1 <= period <= 3650 또는 period=Max)
Period *string `json:"period"`
X509CaParameters *X509CaParameters `json:"X509CaParameters,omitempty"`
}
type CreateCaResponse ¶
type CreateCaResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *CreateCaResponseData `json:"data,omitempty"`
}
type CreateCaResponseData ¶
type CreateCaResponseData struct {
CaInfo *CaInfo `json:"caInfo,omitempty"`
CaCertInfo *CaCertInfo `json:"caCertInfo,omitempty"`
}
type CreateEndCert ¶
type CreateEndCert struct {
// 키 타입
KeyType *string `json:"keyType"`
// 일 단위 인증서 유효 기간. (1 <= period <= 3650 또는 period=Max)
Period *string `json:"period"`
X509EndCertParameters *X509EndCertParameters `json:"X509EndCertParameters"`
}
type GetCaInfoResponse ¶
type GetCaInfoResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *CreateCaResponseData `json:"data,omitempty"`
}
type GetChainResponse ¶
type GetChainResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
// Pem 형식 Chain
Data *string `json:"data,omitempty"`
}
type GetCrlResponse ¶
type GetCrlResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
// Pem 형식 Crl
Data *string `json:"data,omitempty"`
}
type GetEndCertInfoResponse ¶
type GetEndCertInfoResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *GetEndCertInfoResponseData `json:"data,omitempty"`
}
type GetEndCertInfoResponseData ¶
type GetEndCertInfoResponseData struct {
// 인증서 시리얼 번호
SerialNo *string `json:"serialNo,omitempty"`
// 인증서 이름
CommonName *string `json:"commonName,omitempty"`
// 인증서 유효 기간
NotBeforeDate *float32 `json:"notBeforeDate,omitempty"`
// 인증서 만료 기간
NotAfterDate *float32 `json:"notAfterDate,omitempty"`
// 공개키 알고리즘
PublicKeyAlgorithm *string `json:"publicKeyAlgorithm,omitempty"`
// 서명 알고리즘
SignatureAlgorithm *string `json:"signatureAlgorithm,omitempty"`
// Pem 형식 인증서
CertPem *string `json:"certPem,omitempty"`
// Pem 형식 Ca 인증서 체인
CaChain *string `json:"caChain,omitempty"`
// Ocsp Responder 인증서
OcspResponder *string `json:"ocspResponder,omitempty"`
}
type IssueEndCertResponse ¶
type IssueEndCertResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *IssueEndCertResponseData `json:"data,omitempty"`
}
type IssueEndCertResponseData ¶
type IssueEndCertResponseData struct {
// 인증서
Certificate *string `json:"certificate,omitempty"`
// 발행자 인증서
Issuer *string `json:"issuer,omitempty"`
// Ca 인증서 체인
CaChain *string `json:"caChain,omitempty"`
// 인증서 개인키
PrivateKey *string `json:"privateKey,omitempty"`
// 인증서 시리얼 번호
SerialNo *string `json:"serialNo,omitempty"`
// Ocsp Responder 인증서
OcspResponder *string `json:"ocspResponder,omitempty"`
}
type ListCaResponse ¶
type ListCaResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *ListCaResponseData `json:"data,omitempty"`
}
type ListCaResponseData ¶
type ListCaResponseData struct {
// 총 개수
TotalCnt *float32 `json:"totalCnt,omitempty"`
// 총 페이지 수
TotalPageNo *float32 `json:"totalPageNo,omitempty"`
// 현재 페이지
CurrentPageNo *float32 `json:"currentPageNo,omitempty"`
CaInfoList []*CreateCaResponseData `json:"caInfoList,omitempty"`
}
type ListCaUsersResponse ¶
type ListCaUsersResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data []*ListCaUsersResponseData `json:"data,omitempty"`
}
type ListCaUsersResponseData ¶
type ListIssuedEndCertsResponse ¶
type ListIssuedEndCertsResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *ListIssuedEndCertsResponseData `json:"data,omitempty"`
}
type ModifyOcspUrl ¶
type ModifyOcspUrl struct {
OcspServers *string `json:"ocsp_servers"`
}
type ResponseCode ¶
type ResponseCode string
const ( SUCCESS ResponseCode = "SUCCESS" NOT_FOUND ResponseCode = "NOT_FOUND" FORBIDDEN ResponseCode = "FORBIDDEN" INTERNAL_SERVER_ERROR ResponseCode = "INTERNAL_SERVER_ERROR" INVALID_STATUS ResponseCode = "INVALID_STATUS" INVALID_REQUEST ResponseCode = "INVALID_REQUEST" UNAUTHORIZED ResponseCode = "UNAUTHORIZED" UNPROCESSABLE_ENTITY ResponseCode = "UNPROCESSABLE_ENTITY" NOT_AUTHORIZED_REQUEST ResponseCode = "NOT_AUTHORIZED_REQUEST" NOT_AUTHORIZED_ACTION ResponseCode = "NOT_AUTHORIZED_ACTION" EMPTY_NCLOUD_INSTANCE_NO ResponseCode = "EMPTY_NCLOUD_INSTANCE_NO" EMPTY_AUTH_TOKEN ResponseCode = "EMPTY_AUTH_TOKEN" EMPTY_TENANT_ID ResponseCode = "EMPTY_TENANT_ID" EMPTY_ID_NO ResponseCode = "EMPTY_ID_NO" EMPTY_CA_ALIAS ResponseCode = "EMPTY_CA_ALIAS" EMPTY_KEY_TYPE ResponseCode = "EMPTY_KEY_TYPE" EMPTY_CA_TTL ResponseCode = "EMPTY_CA_TTL" EMPTY_COMMON_NAME ResponseCode = "EMPTY_COMMON_NAME" EMPTY_X509_PARAMETERS ResponseCode = "EMPTY_X509_PARAMETERS" EMPTY_CSR ResponseCode = "EMPTY_CSR" EMPTY_CERT ResponseCode = "EMPTY_CERT" EMPTY_STATUS ResponseCode = "EMPTY_STATUS" EMPTY_CA_ID ResponseCode = "EMPTY_CA_ID" EMPTY_ISSUER_ID ResponseCode = "EMPTY_ISSUER_ID" EMPTY_SERIAL_NO ResponseCode = "EMPTY_SERIAL_NO" EMPTY_ACCESS_TOKEN ResponseCode = "EMPTY_ACCESS_TOKEN" EMPTY_CA_TYPE ResponseCode = "EMPTY_CA_TYPE" INVALID_INPUT_CERT ResponseCode = "INVALID_INPUT_CERT" INVALID_INPUT_CA_CHAIN ResponseCode = "INVALID_INPUT_CA_CHAIN" INVALID_INPUT_STATUS ResponseCode = "INVALID_INPUT_STATUS" INVALID_INPUT_PERIOD ResponseCode = "INVALID_INPUT_PERIOD" INVALID_INPUT_PAGENUMBBER ResponseCode = "INVALID_INPUT_PAGENUMBBER" INVALID_INPUT_SERIAL_NO ResponseCode = "INVALID_INPUT_SERIAL_NO" INVALID_INPUT ResponseCode = "INVALID_INPUT" INVALID_PATH ResponseCode = "INVALID_PATH" INVAILD_TENANT_ID ResponseCode = "INVAILD_TENANT_ID" INVAILD_ID_NO ResponseCode = "INVAILD_ID_NO" INVAILD_ACCESS_TOKEN ResponseCode = "INVAILD_ACCESS_TOKEN" INVAILD_ACCESS_TOKEN_TTL ResponseCode = "INVAILD_ACCESS_TOKEN_TTL" INVAILD_POLICY_NAME ResponseCode = "INVAILD_POLICY_NAME" INVALID_USER ResponseCode = "INVALID_USER" INVALID_X509_KEY_TYPE ResponseCode = "INVALID_X509_KEY_TYPE" INVALID_X509_TTL ResponseCode = "INVALID_X509_TTL" INVALID_X509_IP ResponseCode = "INVALID_X509_IP" INVALID_X509_URI ResponseCode = "INVALID_X509_URI" INVALID_X509_OTHER ResponseCode = "INVALID_X509_OTHER" INVALID_X509_KEY_USAGE ResponseCode = "INVALID_X509_KEY_USAGE" INVALID_X509_EXTENDED_KEY_USAGE ResponseCode = "INVALID_X509_EXTENDED_KEY_USAGE" INVALID_CASTORE ResponseCode = "INVALID_CASTORE" INVALID_CASTORE_STATUS ResponseCode = "INVALID_CASTORE_STATUS" INVALID_CA_STATUS ResponseCode = "INVALID_CA_STATUS" INVALID_ISSUER_CA ResponseCode = "INVALID_ISSUER_CA" INVALID_CA ResponseCode = "INVALID_CA" INVALID_ACTION ResponseCode = "INVALID_ACTION" INVALID_CERT ResponseCode = "INVALID_CERT" EXCEED_EXPIRY_DATE ResponseCode = "EXCEED_EXPIRY_DATE" EXCEED_CA_ALIAS ResponseCode = "EXCEED_CA_ALIAS" EXCEED_COMMON_NAME ResponseCode = "EXCEED_COMMON_NAME" EXCEED_SIGNING_COUNT ResponseCode = "EXCEED_SIGNING_COUNT" ALREADY_EXIST_CASTORE ResponseCode = "ALREADY_EXIST_CASTORE" ALREADY_EXIST_ALIAS ResponseCode = "ALREADY_EXIST_ALIAS" ALREADY_EXIST_POLICY ResponseCode = "ALREADY_EXIST_POLICY" ALREADY_EXIST_NCLOUD_INSTANCE_NO ResponseCode = "ALREADY_EXIST_NCLOUD_INSTANCE_NO" NOT_EXIST_CASTORE ResponseCode = "NOT_EXIST_CASTORE" NOT_EXIST_ISSUER_CA ResponseCode = "NOT_EXIST_ISSUER_CA" NOT_EXIST_POLICY ResponseCode = "NOT_EXIST_POLICY" FAIL_BLOC_CREATE_INSTANCE ResponseCode = "FAIL_BLOC_CREATE_INSTANCE" FAIL_BLOC_RETURN_INSTANCE ResponseCode = "FAIL_BLOC_RETURN_INSTANCE" FAIL_CREATE_POLICY ResponseCode = "FAIL_CREATE_POLICY" FAIL_UPDATE_CA ResponseCode = "FAIL_UPDATE_CA" FAIL_SEND_MAIL ResponseCode = "FAIL_SEND_MAIL" FAIL_REQUEST ResponseCode = "FAIL_REQUEST" FAIL_CORE ResponseCode = "FAIL_CORE" )
List of ResponseCode
type SignCsr ¶
type SignCsr struct {
// PEM 포맷의 CSR(인증서 서명 요청)
CsrPem *string `json:"csrPem,omitempty"`
// DER 포맷의 CSR(인증서 서명 요청)
CsrPemDer *[]byte `json:"csrPemDer,omitempty"`
// 인증서 유효 기간. 일 단위 (1 <= period <= 3650 혹은 period=Max)
Period *string `json:"period"`
// 인증서 키 타입
KeyType *string `json:"keyType,omitempty"`
// 인증서 키 Bits
KeyBits *string `json:"keyBits,omitempty"`
}
type SignCsrResponse ¶
type SignCsrResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *SignCsrResponseData `json:"data,omitempty"`
}
type SignCsrResponseData ¶
type SignCsrResponseData struct {
// 인증서
Certificate *string `json:"certificate,omitempty"`
// 발행자 인증서
Issuer *string `json:"issuer,omitempty"`
// Ca 인증서 체인
CaChain *[]string `json:"caChain,omitempty"`
// 인증서 시리얼 번호
SerialNo *string `json:"serialNo,omitempty"`
// Ocsp Responder 인증서
OcspResponder *string `json:"ocspResponder,omitempty"`
}
type UpdateCaResponse ¶
type UpdateCaResponse struct {
Code *ResponseCode `json:"code,omitempty"`
Msg *string `json:"msg,omitempty"`
Data *CaInfo `json:"data,omitempty"`
}
type UpdateCrlConfig ¶
type UpdateCrlConfig struct {
Expiry *string `json:"expiry,omitempty"`
}
type V1ApiService ¶
type V1ApiService service
func (*V1ApiService) CaCaTagActivatePost ¶
func (a *V1ApiService) CaCaTagActivatePost(ctx context.Context, activateSubCa *ActivateSubCa, caTag *string) (*ActivateSubCaResponse, error)
V1ApiService
@param activateSubCa @param caTag caTag @return *ActivateSubCaResponse
func (*V1ApiService) CaCaTagCertGet ¶
func (a *V1ApiService) CaCaTagCertGet(ctx context.Context, caTag *string, localVarOptionals map[string]interface{}) (*ListIssuedEndCertsResponse, error)
V1ApiService
@param caTag caTag @param optional (nil or map[string]interface{}) with one or more of:
@param "pageNo" (string)
@return *ListIssuedEndCertsResponse
func (*V1ApiService) CaCaTagCertPost ¶
func (a *V1ApiService) CaCaTagCertPost(ctx context.Context, createEndCert *CreateEndCert, caTag *string) (*IssueEndCertResponse, error)
V1ApiService
@param createEndCert @param caTag caTag @return *IssueEndCertResponse
func (*V1ApiService) CaCaTagCertSerialNoGet ¶
func (a *V1ApiService) CaCaTagCertSerialNoGet(ctx context.Context, caTag *string, serialNo *string) (*GetEndCertInfoResponse, error)
V1ApiService
@param caTag caTag @param serialNo serialNo @return *GetEndCertInfoResponse
func (*V1ApiService) CaCaTagCertSerialNoRevokePost ¶
func (a *V1ApiService) CaCaTagCertSerialNoRevokePost(ctx context.Context, caTag *string, serialNo *string) (*BaseResponse, error)
V1ApiService
@param caTag caTag @param serialNo serialNo @return *BaseResponse
func (*V1ApiService) CaCaTagCertSignPost ¶
func (a *V1ApiService) CaCaTagCertSignPost(ctx context.Context, signCsr *SignCsr, caTag *string, localVarOptionals map[string]interface{}) (*SignCsrResponse, error)
V1ApiService
@param signCsr @param caTag caTag @param optional (nil or map[string]interface{}) with one or more of:
@param "period" (string)
@return
func (*V1ApiService) CaCaTagChainGet ¶
func (a *V1ApiService) CaCaTagChainGet(ctx context.Context, caTag *string) (*GetChainResponse, error)
V1ApiService
@param caTag caTag @return *GetChainResponse
func (*V1ApiService) CaCaTagCrlConfigGet ¶
func (a *V1ApiService) CaCaTagCrlConfigGet(ctx context.Context, caTag *string) error
V1ApiService
@param caTag caTag @return
func (*V1ApiService) CaCaTagCrlConfigPut ¶
func (a *V1ApiService) CaCaTagCrlConfigPut(ctx context.Context, updateCrlConfig *UpdateCrlConfig, caTag *string) error
V1ApiService
@param updateCrlConfig @param caTag caTag @return
func (*V1ApiService) CaCaTagCrlGet ¶
func (a *V1ApiService) CaCaTagCrlGet(ctx context.Context, caTag *string) (*GetCrlResponse, error)
V1ApiService
@param caTag caTag @return *GetCrlResponse
func (*V1ApiService) CaCaTagDelete ¶
func (a *V1ApiService) CaCaTagDelete(ctx context.Context, caTag *string) (*BaseResponse, error)
V1ApiService
@param caTag caTag @return *BaseResponse
func (*V1ApiService) CaCaTagGet ¶
func (a *V1ApiService) CaCaTagGet(ctx context.Context, caTag *string) (*GetCaInfoResponse, error)
V1ApiService
@param caTag caTag @return *GetCaInfoResponse
func (*V1ApiService) CaCaTagPut ¶
func (a *V1ApiService) CaCaTagPut(ctx context.Context, updateCa *UpdateCa, caTag *string) (*UpdateCaResponse, error)
V1ApiService
@param updateCa @param caTag caTag @return *UpdateCaResponse
func (*V1ApiService) CaCaTagSubCsrGet ¶
func (a *V1ApiService) CaCaTagSubCsrGet(ctx context.Context, caTag *string) error
V1ApiService
@param caTag caTag @return
func (*V1ApiService) CaCaTagSubSignPost ¶
func (a *V1ApiService) CaCaTagSubSignPost(ctx context.Context, signCsr *SignCsr, caTag *string) error
V1ApiService
@param signCsr @param caTag caTag @return
func (*V1ApiService) CaCaTagTrimPost ¶
func (a *V1ApiService) CaCaTagTrimPost(ctx context.Context, caTag *string) error
V1ApiService
@param caTag caTag @return
func (*V1ApiService) CaCaTagUrlsDelete ¶
func (a *V1ApiService) CaCaTagUrlsDelete(ctx context.Context, caTag *string) error
V1ApiService
@param caTag caTag @return
func (*V1ApiService) CaCaTagUrlsPut ¶
func (a *V1ApiService) CaCaTagUrlsPut(ctx context.Context, modifyOcspUrl *ModifyOcspUrl, caTag *string) error
V1ApiService
@param modifyOcspUrl @param caTag caTag @return
func (*V1ApiService) CaCaTagUsersGet ¶
func (a *V1ApiService) CaCaTagUsersGet(ctx context.Context, caTag *string) (*ListCaUsersResponse, error)
V1ApiService
@param caTag caTag @return *ListCaUsersResponse
func (*V1ApiService) CaCaTagUsersIdNoDelete ¶
func (a *V1ApiService) CaCaTagUsersIdNoDelete(ctx context.Context, caTag *string, idNo *string) (*BaseResponse, error)
V1ApiService
@param caTag caTag @param idNo idNo @return *BaseResponse
func (*V1ApiService) CaCaTagUsersPost ¶
func (a *V1ApiService) CaCaTagUsersPost(ctx context.Context, addCaUser *AddCaUser, caTag *string) (*BaseResponse, error)
V1ApiService
@param addCaUser @param caTag caTag @return *BaseResponse
func (*V1ApiService) CaGet ¶
func (a *V1ApiService) CaGet(ctx context.Context, localVarOptionals map[string]interface{}) (*ListCaResponse, error)
V1ApiService
@param optional (nil or map[string]interface{}) with one or more of:
@param "pageNo" (int32)
@return *ListCaResponse
func (*V1ApiService) CaPost ¶
func (a *V1ApiService) CaPost(ctx context.Context, createCa *CreateCa, caType *string, localVarOptionals map[string]interface{}) (*CreateCaResponse, error)
V1ApiService
@param createCa @param caType @param optional (nil or map[string]interface{}) with one or more of:
@param "issuerId" (int64)
@return *CreateCaResponse
type X509CaParameters ¶
type X509CaParameters struct {
// 인증서 이름 혹은 도메인. 최대 64자 입력 가능
CommonName *string `json:"commonName"`
// 인증서의 다른 이름
AltName *string `json:"altName,omitempty"`
// 인증서에 해당하는 IP, \",\" 구분자 리스트
Ip *string `json:"ip,omitempty"`
// 국가
Country *string `json:"country,omitempty"`
// 회사
Organization *string `json:"organization,omitempty"`
// 조직
OrganizationUnit *string `json:"organizationUnit,omitempty"`
// 도시
Locality *string `json:"locality,omitempty"`
// 구/동
StateProvince *string `json:"stateProvince,omitempty"`
}
type X509EndCertParameters ¶
type X509EndCertParameters struct {
// 인증서 이름 혹은 도메인. 최대 64자 입력 가능
CommonName *string `json:"commonName"`
// 인증서의 다른 이름
AltName *string `json:"altName,omitempty"`
// 인증서에 해당하는 IP, \",\" 구분자 리스트
Ip *string `json:"ip,omitempty"`
// 인증서에 해당하는 URI, \",\" 구분자 리스트
Uri *string `json:"uri,omitempty"`
// 기타 인증서 정보, {OID};UTF8:{value} 포맷, \",\" 구분자 리스트
Other *string `json:"other,omitempty"`
// 국가
Country *string `json:"country,omitempty"`
// 회사
Organization *string `json:"organization,omitempty"`
// 조직
OrganizationUnit *string `json:"organizationUnit,omitempty"`
// 도시
Locality *string `json:"locality,omitempty"`
// 구/동
StateProvince *string `json:"stateProvince,omitempty"`
// 도로명
StreetAddress *string `json:"streetAddress,omitempty"`
// 우편번호
PostalCode *string `json:"postalCode,omitempty"`
// CSR 설정 값 사용 여부
UseCnAsSan *bool `json:"useCnAsSan,omitempty"`
// 키 용도
KeyUsage []*string `json:"keyUsage,omitempty"`
// 확장 키 용도
ExtendedKeyUsage []*string `json:"extendedKeyUsage,omitempty"`
}
Source Files
¶
- activate_sub_ca.go
- activate_sub_ca_response.go
- add_ca_user.go
- api_client.go
- api_response.go
- base_response.go
- ca_cert_info.go
- ca_info.go
- ca_info_url_info.go
- configuration.go
- create_ca.go
- create_ca_response.go
- create_ca_response_data.go
- create_end_cert.go
- get_ca_info_response.go
- get_chain_response.go
- get_crl_response.go
- get_end_cert_info_response.go
- get_end_cert_info_response_data.go
- issue_end_cert_response.go
- issue_end_cert_response_data.go
- list_ca_response.go
- list_ca_response_data.go
- list_ca_users_response.go
- list_ca_users_response_data.go
- list_issued_end_certs_response.go
- list_issued_end_certs_response_data.go
- modify_ocsp_url.go
- response_code.go
- sign_csr.go
- sign_csr_response.go
- sign_csr_response_data.go
- update_ca.go
- update_ca_response.go
- update_crl_config.go
- v1_api.go
- x509_ca_parameters.go
- x509_end_cert_parameters.go